import{C as t,E as i,K as d,a as c,M as b,c as l,P as y,R as f,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.4c41f8a1.js";import"./vue-router.78d58ff0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="5880cb33-01be-4c65-a82e-9686a1725c81",e._sentryDebugIdIdentifier="sentry-dbid-5880cb33-01be-4c65-a82e-9686a1725c81")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,c as KeyMod,b as MarkerSeverity,l as MarkerTag,y as Position,f as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.84928b3c.js.map
