import{P as m}from"./PlayerNavbar.f223d3d1.js";import{u as _,b as f}from"./router.08432de3.js";import{d as h,eO as g,eB as s,f as b,r as y,W as v,b as r,u as i,a as w,o as L,$ as I}from"./vue-router.78d58ff0.js";import"./metadata.5a21999c.js";import"./PhCheckCircle.vue.3b4eb234.js";import"./PhKanban.vue.78518561.js";import"./PhWebhooksLogo.vue.307cd289.js";import"./PhSignOut.vue.f80d6de9.js";import"./workspaceStore.48fc9b8b.js";import"./api.eee349cf.js";import"./runnerData.d455da29.js";import"./url.f92f4d36.js";import"./index.20fea1a7.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="daff489a-02b7-4070-a67e-04ce3b912d39",t._sentryDebugIdIdentifier="sentry-dbid-daff489a-02b7-4070-a67e-04ce3b912d39")}catch{}})();const k={class:"main-container"},N={class:"content"},x=h({__name:"Main",setup(t){const e=g(),o=_(),c=s().path,u=({path:n})=>{e.push({path:`/${n}`})},d=()=>{e.push({name:"playerLogin"})},p=b(()=>!!s().meta.hideLogin);return f(()=>e.push({name:"playerLogin"})),(n,B)=>{var a;const l=y("RouterView");return L(),v("div",k,[r(m,{"current-path":i(c),"user-email":(a=i(o).user)==null?void 0:a.claims.email,"hide-login":p.value,onNavigate:u,onLoginClick:d},null,8,["current-path","user-email","hide-login"]),w("section",N,[r(l)])])}}});const q=I(x,[["__scopeId","data-v-9c4cb6a6"]]);export{q as default};
//# sourceMappingURL=Main.599243f4.js.map
