import{d as i,r as c,u as a,o as p,c as d,w as m,b as u,R as l,k as f,T as _,m as w,P as g,C as y,M as b,s as h,n as s,p as k,q as v,t as C,v as I}from"./vue-router.78d58ff0.js";import{s as W,c as V,a as o}from"./router.08432de3.js";import{W as A}from"./WidgetsFrame.fcf54d4b.js";import{u as D}from"./workspaceStore.48fc9b8b.js";import"./api.eee349cf.js";import"./runnerData.d455da29.js";import"./url.f92f4d36.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="d48a4b14-e239-409a-a1d2-ce1b6a9bcd9e",t._sentryDebugIdIdentifier="sentry-dbid-d48a4b14-e239-409a-a1d2-ce1b6a9bcd9e")}catch{}})();const M=i({__name:"App",setup(t){const e=D();return e.actions.fetch(),(n,S)=>{const r=c("RouterView");return a(e).state.workspace?(p(),d(A,{key:0,"main-color":a(e).state.workspace.mainColor,theme:a(e).state.workspace.theme,"font-family":a(e).state.workspace.fontFamily,locale:a(e).state.workspace.language},{default:m(()=>[u(r,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","theme","font-family","locale"])):l("",!0)}}});class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await W();const t=V(),e=f({render:()=>k(M)});_.init(),w(e,o),P.init(),e.use(o),e.use(t),e.use(g),e.mount("#app"),e.component("VSelect",y),e.component("Markdown",b),e.component("Message",h),s(e,v),s(e,C),s(e,I)})();
//# sourceMappingURL=player.9261e032.js.map
