import{L as D}from"./LoadingContainer.d5b2184d.js";import{S as x}from"./SaveButton.32286291.js";import{C as A,W as h}from"./model.0518f535.js";import{E as C}from"./api.1c2313c5.js";import{d as E,e as W,f as B,u as t,c as i,W as _,R as y,b as d,w as o,o as r,a as w,aJ as N,eD as V,cV as k,ax as m,eA as f,eE as S,cB as G,c_ as L,$ as T}from"./vue-router.78d58ff0.js";import{w as F}from"./metadata.5a21999c.js";import{a as M}from"./asyncComputed.95993e52.js";import{A as I}from"./index.e96c19f7.js";import{A as J}from"./index.6af03e92.js";import"./ExclamationCircleOutlined.f0dc7247.js";import"./workspaces.c5ca84af.js";import"./runnerData.d455da29.js";import"./url.f92f4d36.js";import"./record.6c05e3f5.js";import"./validations.ee2ef856.js";import"./string.b574f1fa.js";import"./PhArrowSquareOut.vue.f7ba9bd2.js";import"./index.8fd76c0b.js";import"./Badge.84ae1b1f.js";import"./isNumeric.75337b1e.js";import"./index.aab54164.js";import"./Card.e6564a3e.js";import"./TabPane.e15de9cc.js";import"./uuid.34b93336.js";import"./fetch.6b493350.js";import"./PhCheckCircle.vue.3b4eb234.js";import"./PhKanban.vue.78518561.js";import"./PhWebhooksLogo.vue.307cd289.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[n]="739c7360-8bf2-41ad-80ea-bc39956b4844",s._sentryDebugIdIdentifier="sentry-dbid-739c7360-8bf2-41ad-80ea-bc39956b4844")}catch{}})();const P={key:1,class:"workflow-editor"},R={class:"workflow-toolbar"},$=["onDragstart"],j=E({__name:"WorkflowEditor",setup(s){const n=W(null),u=B(()=>{var a;return(a=n.value)==null?void 0:a.gui}),v=new C,{result:l,loading:b}=M(()=>h.create(v)),g=(a,c)=>{var e,p;(e=c.dataTransfer)==null||e.setData("type",a),(p=u.value)==null||p.dragstart(a,c)};return(a,c)=>t(b)?(r(),i(D,{key:0})):(r(),_("div",P,[t(l)?(r(),i(A,{key:0,ref_key:"canvasGui",ref:n,model:t(l)},null,8,["model"])):y("",!0),d(t(L),null,{default:o(()=>[w("div",R,[(r(!0),_(N,null,V(t(F).stages,e=>(r(),i(t(G),{key:e.typeName,placement:"top"},{title:o(()=>[d(t(I),null,{default:o(()=>[d(t(k),null,{default:o(()=>[m(f(e.title),1)]),_:2},1024),d(t(k),{keyboard:""},{default:o(()=>[m(f(e.key),1)]),_:2},1024)]),_:2},1024)]),content:o(()=>[m(f(e.description),1)]),default:o(()=>[w("span",{draggable:"true",onDragstart:p=>g(e.typeName,p)},[(r(),i(S(e.icon),{width:"18",height:"18",class:"toolbar-item"}))],40,$)]),_:2},1024))),128)),d(t(J),{type:"vertical"}),t(l)?(r(),i(x,{key:0,model:t(l),disabled:void 0,type:"primary"},null,8,["model"])):y("",!0)])]),_:1})]))}});const kt=T(j,[["__scopeId","data-v-de9c06f6"]]);export{kt as default};
//# sourceMappingURL=WorkflowEditor.93bf173f.js.map
