import{d as n,W as d,a as s,Z as a,ey as r,o as l,$ as _}from"./vue-router.78d58ff0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8c3053dd-b8b0-4ad2-ba24-55e3e0e2fbbd",e._sentryDebugIdIdentifier="sentry-dbid-8c3053dd-b8b0-4ad2-ba24-55e3e0e2fbbd")}catch{}})();const c={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(l(),d("div",c,[s("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[a(t.$slots,"default",{},void 0,!0)],2)]))}});const f=_(u,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.d34b8e7d.js.map
