import{W as g}from"./Watermark.e5cf2622.js";import{i as h}from"./metadata.5a21999c.js";import{F as k}from"./PhArrowSquareOut.vue.f7ba9bd2.js";import{d as w,eO as x,f as b,u as e,W as m,b as o,w as r,R as v,o as s,c as p,ax as u,cS as f,aJ as C,eD as D,c_ as _,eE as I,eA as F,$ as S}from"./vue-router.78d58ff0.js";import{u as T}from"./workspaceStore.48fc9b8b.js";import"./index.723c8012.js";import{C as W}from"./Card.e6564a3e.js";import"./router.08432de3.js";import"./PhCheckCircle.vue.3b4eb234.js";import"./PhKanban.vue.78518561.js";import"./PhWebhooksLogo.vue.307cd289.js";import"./api.eee349cf.js";import"./runnerData.d455da29.js";import"./url.f92f4d36.js";import"./TabPane.e15de9cc.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="66257c69-03c1-4956-a045-87ae2d572396",t._sentryDebugIdIdentifier="sentry-dbid-66257c69-03c1-4956-a045-87ae2d572396")}catch{}})();const z={key:0,class:"home-container"},B=w({__name:"Home",setup(t){const n=x(),c=T(),l=b(()=>{var a;return((a=c.state.workspace)==null?void 0:a.sidebar.filter(d=>d.id!=="home"))||[]}),y=a=>{n.push({path:`/${a}`})};return(a,d)=>e(c).state.workspace?(s(),m("div",z,[o(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[l.value.length===0?(s(),p(e(f),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[u(" There are no forms available for you. ")]),_:1})):(s(!0),m(C,{key:1},D(l.value,i=>(s(),p(e(W),{key:i.id,class:"form-card",onClick:E=>y(i.path)},{default:r(()=>[o(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(s(),p(I(e(h)(i.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),o(e(f),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[u(F(i.name),1)]),_:2},1024),o(e(k),{size:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}),o(g,{class:"watermark","page-id":"home",locale:e(c).state.workspace.language},null,8,["locale"])])):v("",!0)}});const Q=S(B,[["__scopeId","data-v-2ee244f8"]]);export{Q as default};
//# sourceMappingURL=Home.280bf675.js.map
