import{u as k}from"./router.08432de3.js";import{d as _,L as w,N as b,e as g,W as v,b as a,w as h,u as e,c as p,R as m,o as s,$ as T}from"./vue-router.78d58ff0.js";import{K,_ as R,W as I,P,b as S}from"./WorkflowView.ca3bf66c.js";import{P as V}from"./api.1c2313c5.js";import{A as c,T as W}from"./TabPane.e15de9cc.js";import"./Card.e6564a3e.js";import"./fetch.6b493350.js";import"./linters.6b1b67ed.js";import"./asyncComputed.95993e52.js";import"./scripts.23271152.js";import"./record.6c05e3f5.js";import"./metadata.5a21999c.js";import"./PhCheckCircle.vue.3b4eb234.js";import"./PhKanban.vue.78518561.js";import"./PhWebhooksLogo.vue.307cd289.js";import"./ant-design.f29af77f.js";import"./index.e96c19f7.js";import"./index.8e2351ec.js";import"./index.6bbf453b.js";import"./index.aa9087e7.js";import"./CollapsePanel.3b0981c6.js";import"./index.6af03e92.js";import"./index.3a877807.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.91d84d7e.js";import"./model.0518f535.js";import"./workspaces.c5ca84af.js";import"./runnerData.d455da29.js";import"./url.f92f4d36.js";import"./validations.ee2ef856.js";import"./string.b574f1fa.js";import"./PhArrowSquareOut.vue.f7ba9bd2.js";import"./index.8fd76c0b.js";import"./Badge.84ae1b1f.js";import"./index.aab54164.js";import"./uuid.34b93336.js";import"./LoadingOutlined.734d4a55.js";import"./DeleteOutlined.77ef7301.js";import"./PhDownloadSimple.vue.773928bf.js";import"./utils.d432b283.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="9fb69949-f7e1-4f68-8c45-2488c1dc3a23",t._sentryDebugIdIdentifier="sentry-dbid-9fb69949-f7e1-4f68-8c45-2488c1dc3a23")}catch{}})();const x={class:"threads-view"},A=_({__name:"Threads",setup(t){const r=k().authHeaders,u=new V(r),i=new P(r),d=new S(r),f=new w(b.array(b.string()),"kanban-selected-stages"),o=g("kanban");return(B,l)=>(s(),v("div",x,[a(e(W),{activeKey:o.value,"onUpdate:activeKey":l[0]||(l[0]=y=>o.value=y)},{default:h(()=>[a(e(c),{key:"kanban",tab:"Kanban View"}),a(e(c),{key:"table",tab:"Table View"}),a(e(c),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(s(),p(K,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(f),"stage-run-repository":e(d)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(s(),p(R,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(s(),p(I,{key:2,"kanban-repository":e(i),"workflow-api":e(u)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=T(A,[["__scopeId","data-v-86c0b860"]]);export{ge as default};
//# sourceMappingURL=Threads.247c52cb.js.map
