import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.ee669a14.js";import{d as i,eB as s,c,u as m,o as a}from"./vue-router.78d58ff0.js";import"./gateway.3d93841d.js";import"./popupNotifcation.466d80c0.js";import"./fetch.6b493350.js";import"./record.6c05e3f5.js";import"./SaveButton.32286291.js";import"./ExclamationCircleOutlined.f0dc7247.js";import"./CrudView.f04f853e.js";import"./router.ce687edb.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.c6ea29d9.js";import"./BookOutlined.238416cb.js";import"./url.f92f4d36.js";import"./PhDotsThree.vue.4c71ca22.js";import"./index.8e2351ec.js";import"./index.e96c19f7.js";import"./PhRocketLaunch.vue.6c584205.js";import"./asyncComputed.95993e52.js";import"./PhPencil.vue.50044340.js";import"./index.aab54164.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="94c2cb26-cc26-42f1-8f9b-f76dfca8bfcb",o._sentryDebugIdIdentifier="sentry-dbid-94c2cb26-cc26-42f1-8f9b-f76dfca8bfcb")}catch{}})();const q=i({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(f,d)=>(a(),c(n,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{q as default};
//# sourceMappingURL=EnvVars.ad599489.js.map
