import{B as _}from"./BaseLayout.ca3956cd.js";import{L as y}from"./Logo.1643f166.js";import{d as u,D as m,K as g,$ as p,aR as v,aS as b,o as f,W as h,a,X as n,eB as w,eO as S,V as L,c as k,w as r,b as i,u as B}from"./vue-router.78d58ff0.js";import{u as x}from"./editor.e89ed34e.js";import{b as I}from"./index.ffdb60ac.js";import"./router.08432de3.js";import"./linters.6b1b67ed.js";import"./asyncComputed.95993e52.js";import"./index.20fea1a7.js";import"./index.e96c19f7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="28f4f236-4d99-40f0-87cc-32268d6c68df",e._sentryDebugIdIdentifier="sentry-dbid-28f4f236-4d99-40f0-87cc-32268d6c68df")}catch{}})();const $=u({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...g(o)}}});const D={class:"v-spinner"};function P(e,o,s,c,d,l){return v((f(),h("div",D,[a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[b,e.loading]])}const R=p($,[["render",P],["__scopeId","data-v-06538001"]]),K={class:"content"},j=u({__name:"ProjectLogin",setup(e){const o=w(),s=S(),c=x();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),s.replace(t.pathname+t.search)}function l(){const t=o.query["api-key"];if(typeof t=="string")return t}return L(async()=>{const t=l();if(!t){s.push({name:"error"});return}await c.createLogin(t).then(d),s.push({name:"workspace"})}),(t,z)=>(f(),k(_,null,{navbar:r(()=>[i(B(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:r(()=>[i(y)]),_:1})]),content:r(()=>[a("div",K,[i(R)])]),_:1}))}});const O=p(j,[["__scopeId","data-v-6ca995fe"]]);export{O as default};
//# sourceMappingURL=ProjectLogin.360b255e.js.map
