import{d,f as p,o as n,W as a,a as o,aJ as l,eD as r,ey as f,eA as _,R as i,$ as u}from"./vue-router.78d58ff0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="0c452f18-fdb9-4989-b36a-bfb6d8dd7dda",e._sentryDebugIdIdentifier="sentry-dbid-0c452f18-fdb9-4989-b36a-bfb6d8dd7dda")}catch{}})();const b={key:0,class:"p-steps p-component"},m={class:"p-steps-list"},y={class:"p-menuitem-link"},g={class:"p-steps-number"},I=d({__name:"Steps",props:{stepsInfo:{type:Object,default:null}},setup(e){const s=e,c=p(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",to:""})):[]);return(h,k)=>e.stepsInfo?(n(),a("nav",b,[o("ol",m,[(n(!0),a(l,null,r(c.value,(v,t)=>(n(),a("li",{key:t,class:f(["p-steps-item",{"p-highlight":t+1===e.stepsInfo.current}])},[o("span",y,[o("span",g,_(t+1),1)])],2))),128))])])):i("",!0)}});const w=u(I,[["__scopeId","data-v-c916ecf3"]]);export{w as S};
//# sourceMappingURL=Steps.9fbe8d52.js.map
