import{d as h,eO as A,r as B,u as e,o as s,c as i,bp as C,W as f,b as a,w as t,ax as r,bL as d,a as m,cV as w,eA as _,cB as L,eM as N,eD as D,fd as I,aJ as g,R,Z as z,$ as S}from"./vue-router.78d58ff0.js";import{a as V}from"./asyncComputed.95993e52.js";import{G as $}from"./PhChats.vue.a9cb8ab5.js";import{F as T}from"./PhSignOut.vue.f80d6de9.js";import{C as E}from"./router.ce687edb.js";import{a as k}from"./gateway.3d93841d.js";import{A as F}from"./index.e96c19f7.js";import{A as M}from"./index.20fea1a7.js";import{B as O,A as P,b as j}from"./index.ffdb60ac.js";import{B as q}from"./BookOutlined.238416cb.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[o]="5a7b0cea-df0b-4f95-a96a-6361546d8816",n._sentryDebugIdIdentifier="sentry-dbid-5a7b0cea-df0b-4f95-a96a-6361546d8816")}catch{}})();const G={key:1,style:{display:"flex","align-items":"center",gap:"16px"}},H={style:{display:"flex","flex-direction":"column",gap:"10px"}},J={style:{display:"flex",gap:"5px"}},U=h({__name:"LoginBlock",setup(n){function o(b){const y=b.split("@")[0];return N.exports.kebabCase(y).toUpperCase().split("-").slice(0,2).map(u=>u[0]).join("")}const c=A(),{result:l,loading:p,refetch:x}=V(async()=>k.getAuthor());function v(){k.removeAuthor(),E.shutdown(),x(),c.push({name:"login"})}return(b,y)=>{const u=B("RouterLink");return e(p)?(s(),i(e(C),{key:0})):e(l)?(s(),f("div",G,[a(e(d),{class:"intercom-launcher",target:"_blank",type:"link",size:"small",style:{color:"#d14056",display:"flex","align-items":"center",gap:"6px"}},{icon:t(()=>[a(e($),{size:18})]),default:t(()=>[r(" Support ")]),_:1}),a(e(L),{placement:"bottomRight"},{content:t(()=>[m("div",H,[a(e(w),{size:"small",type:"secondary"},{default:t(()=>[r(_(e(l).claims.email),1)]),_:1}),a(e(d),{type:"text",onClick:v},{default:t(()=>[m("div",J,[a(e(T),{size:"20"}),r(" Logout ")])]),_:1})])]),default:t(()=>[a(e(F),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[a(e(M),{shape:"square"},{default:t(()=>[r(_(o(e(l).claims.email)),1)]),_:1})]),_:1})]),_:1})])):(s(),i(e(d),{key:2},{default:t(()=>[a(u,{to:"/login"},{default:t(()=>[r("Login")]),_:1})]),_:1}))}}}),W={class:"extra"},Z=h({__name:"Navbar",props:{breadcrumb:{}},setup(n){return(o,c)=>(s(),i(e(j),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[o.breadcrumb?(s(),i(e(O),{key:0},{default:t(()=>[(s(!0),f(g,null,D(o.breadcrumb,(l,p)=>(s(),i(e(P),{key:p},{default:t(()=>[a(e(I),{to:l.path},{default:t(()=>[r(_(l.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):R("",!0)]),extra:t(()=>[m("div",W,[a(e(d),{class:"docs-button",href:"https://docs.abstra.io/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[a(e(q))]),default:t(()=>[o.$slots.default?z(o.$slots,"default",{key:0},void 0,!0):(s(),f(g,{key:1},[r("Docs")],64))]),_:3}),a(U)])]),_:3}))}});const ne=S(Z,[["__scopeId","data-v-5ef7b378"]]);export{ne as N};
//# sourceMappingURL=Navbar.f90abc27.js.map
