import{O as r}from"./router.08432de3.js";import{d as l,V as c,W as u,b as a,w as n,u as o,o as i,ax as s,cW as f,cV as b}from"./vue-router.78d58ff0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c0e13386-6cb3-4871-a8a2-b3b8d2ad3609",e._sentryDebugIdIdentifier="sentry-dbid-c0e13386-6cb3-4871-a8a2-b3b8d2ad3609")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return c(async()=>{await new r().logoutCallback()}),(t,d)=>(i(),u("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.c0f11f4b.js.map
