import{e_ as t,e$ as d}from"./vue-router.78d58ff0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="05c4edba-97e0-46c3-8dc7-d51951c2e9b2",e._sentryDebugIdIdentifier="sentry-dbid-05c4edba-97e0-46c3-8dc7-d51951c2e9b2")}catch{}})();function s(e,n){return t(1,arguments),d(e,Date.now(),n)}export{s as f};
//# sourceMappingURL=index.6bbf453b.js.map
