import{d as o}from"./router.08432de3.js";import{g as t}from"./api.eee349cf.js";import{e as s}from"./vue-router.78d58ff0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="045ebadb-fbef-4875-aaf2-176226506ff9",e._sentryDebugIdIdentifier="sentry-dbid-045ebadb-fbef-4875-aaf2-176226506ff9")}catch{}})();const i=o("workspace",()=>{const e=s({workspace:null,loading:!1});return{state:e,actions:{async fetch(){e.value.loading=!0,e.value.workspace=await t(),e.value.loading=!1}}}});export{i as u};
//# sourceMappingURL=workspaceStore.48fc9b8b.js.map
