import{_ as c}from"./Login.vue_vue_type_script_setup_true_lang.e76fb666.js";import{u as d}from"./router.08432de3.js";import{d as _,eO as u,eB as i,W as f,b as p,o as b,$ as m}from"./vue-router.78d58ff0.js";import"./CircularLoading.f8a423e1.js";import"./index.aab54164.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="deeaae4b-3bad-4bcf-99cb-7aa2e737825a",e._sentryDebugIdIdentifier="sentry-dbid-deeaae4b-3bad-4bcf-99cb-7aa2e737825a")}catch{}})();const y={class:"runner"},l=_({__name:"Login",setup(e){const t=u(),o=i(),n=d(),r=async()=>{await n.signUp();const{redirect:s,...a}=o.query;if(s){await t.push({path:s,query:a,params:o.params});return}t.push({name:"playerHome",query:a})};return(s,a)=>(b(),f("div",y,[p(c,{onDone:r})]))}});const D=m(l,[["__scopeId","data-v-5b8c1f5f"]]);export{D as default};
//# sourceMappingURL=Login.28aabb8a.js.map
