import{O as d}from"./router.08432de3.js";import{d as l,V as i,W as c,b as a,w as n,u as o,o as u,ax as s,cW as f,cV as b}from"./vue-router.78d58ff0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="089f050e-b6ec-48b4-bb5f-5d71b0343ea2",e._sentryDebugIdIdentifier="sentry-dbid-089f050e-b6ec-48b4-bb5f-5d71b0343ea2")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new d().loginCallback()}),(t,r)=>(u(),c("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.f0d809b0.js.map
