import{B as d}from"./BookOutlined.238416cb.js";import{d as c,o as s,c as f,w as o,b as l,u as n,Z as b,W as u,ax as i,aJ as p,bL as y}from"./vue-router.78d58ff0.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="dcab8b84-4c6e-4ec5-a540-b17742b02ffd",t._sentryDebugIdIdentifier="sentry-dbid-dcab8b84-4c6e-4ec5-a540-b17742b02ffd")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var a;return s(),f(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[l(n(d))]),default:o(()=>[e.$slots.default?b(e.$slots,"default",{key:0}):(s(),u(p,{key:1},[i("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.c6ea29d9.js.map
