import{S as c,dm as s}from"./vue-router.78d58ff0.js";import{g as i}from"./index.3a3c317d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="9f6a8f24-3f7d-48c6-99c1-82d2ad4994d5",e._sentryDebugIdIdentifier="sentry-dbid-9f6a8f24-3f7d-48c6-99c1-82d2ad4994d5")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:a}=i(s),y=c(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:a,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,a as R,r as W};
//# sourceMappingURL=dayjs.f93a370e.js.map
