import{d as i,c as p,w as n,o as d,b as a,u as r}from"./vue-router.78d58ff0.js";import"./linters.6b1b67ed.js";import{W as m}from"./workspaces.c5ca84af.js";import{C as s}from"./ContentLayout.d34b8e7d.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.ee669a14.js";import"./asyncComputed.95993e52.js";import"./runnerData.d455da29.js";import"./url.f92f4d36.js";import"./record.6c05e3f5.js";import"./gateway.3d93841d.js";import"./popupNotifcation.466d80c0.js";import"./fetch.6b493350.js";import"./SaveButton.32286291.js";import"./ExclamationCircleOutlined.f0dc7247.js";import"./CrudView.f04f853e.js";import"./router.ce687edb.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.c6ea29d9.js";import"./BookOutlined.238416cb.js";import"./PhDotsThree.vue.4c71ca22.js";import"./index.8e2351ec.js";import"./index.e96c19f7.js";import"./PhRocketLaunch.vue.6c584205.js";import"./PhPencil.vue.50044340.js";import"./index.aab54164.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6a9734e4-a6c5-4d1d-bc9b-2f0e9628edde",e._sentryDebugIdIdentifier="sentry-dbid-6a9734e4-a6c5-4d1d-bc9b-2f0e9628edde")}catch{}})();const z=i({__name:"EnvVarsEditor",setup(e){const o=new c;return(t,u)=>(d(),p(s,null,{default:n(()=>[a(f,{"env-var-repository":r(o),mode:"editor","file-opender":r(m)},null,8,["env-var-repository","file-opender"])]),_:1}))}});export{z as default};
//# sourceMappingURL=EnvVarsEditor.e8042d96.js.map
