import{cz as o}from"./vue-router.78d58ff0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="11906a16-5e98-4855-b943-521310efe852",e._sentryDebugIdIdentifier="sentry-dbid-11906a16-5e98-4855-b943-521310efe852")}catch{}})();const d=(e,r,n)=>{o.error({message:e,description:r,onClick:n})};export{d as p};
//# sourceMappingURL=popupNotifcation.466d80c0.js.map
