import{d as t,o,W as s,b as d,u as r,bp as _,$ as c}from"./vue-router.78d58ff0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="da8ff3a8-be75-4b51-bc60-0d1f55a625f3",e._sentryDebugIdIdentifier="sentry-dbid-da8ff3a8-be75-4b51-bc60-0d1f55a625f3")}catch{}})();const f={class:"centered"},i=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",f,[d(r(_))]))}});const b=c(i,[["__scopeId","data-v-52e6209a"]]);export{b as L};
//# sourceMappingURL=LoadingContainer.d5b2184d.js.map
