import{d as c,eI as n,f as _,o as a,W as d,R as r,eJ as p,eK as i,a as l,$ as g}from"./vue-router.78d58ff0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="951c77bd-7398-4530-a5e2-a437d996cb4c",e._sentryDebugIdIdentifier="sentry-dbid-951c77bd-7398-4530-a5e2-a437d996cb4c")}catch{}})();const u="/assets/logo.0faadfa2.svg",f=e=>(p("data-v-45e099d5"),e=e(),i(),e),b={class:"logo"},y=f(()=>l("img",{class:"logo-img",src:u,alt:"Abstra Logo"},null,-1)),m={key:0},h=c({__name:"Logo",props:{hideText:{type:Boolean},size:{}},setup(e){const s=e;n(t=>({"6b21c5f6":o.value}));const o=_(()=>s.size==="large"?"60px":"40px");return(t,I)=>(a(),d("div",b,[y,t.hideText?r("",!0):(a(),d("span",m,"Abstra"))]))}});const x=g(h,[["__scopeId","data-v-45e099d5"]]);export{x as L};
//# sourceMappingURL=Logo.1643f166.js.map
